@@ -800,6 +800,7 @@ If called from a group buffer, automatically adds GROUP property."
 AUTHOR-URL is the URL of the post author.
 TIMESTAMP is the timestamp of the post being reacted to."
   (interactive)
+  (require 'emojify nil t)
   (if (fboundp 'emojify-completing-read)
       (let ((selected-emoji (emojify-completing-read "Select reaction: ")))
         (when selected-emoji
@@ -868,7 +869,7 @@ Returns t if button was found and pressed, nil otherwise."
 (defun org-social-ui--view-thread ()
   "View thread for current post by pressing the Thread button."
   (interactive)
-  (unless (org-social-ui--find-and-press-button "🧵 Thread")
+  (unless (org-social-ui--find-and-press-button "🧵")
     (message "No thread button found near point")))
 
 (defun org-social-ui--view-notifications ()
@@ -879,7 +880,7 @@ Returns t if button was found and pressed, nil otherwise."
 (defun org-social-ui--view-profile ()
   "View profile for current post by pressing the Profile button."
   (interactive)
-  (unless (org-social-ui--find-and-press-button "👤 Profile")
+  (unless (org-social-ui--find-and-press-button "👤")
     (message "No profile button found near point")))
 
 (defun org-social-ui--view-groups ()
